@@ -7,7 +7,7 @@ from tek import Configurations, logger
 from tek_utils.sharehoster.common import ProgressPrinter
 
 
-class ProgressPrinterTest(spec.Spec, ):
+class ProgressPrinter_(spec.Spec, ):
 
     class _Terminal(object):
 
@@ -41,12 +41,4 @@ class ProgressPrinterTest(spec.Spec, ):
                     '110.00% ||    1.1 KB of 1000.0 B  || at     0.00 B/s']
         terminal.log.should.be(expected)
 
-    def testfoo(self):
-        try:
-            raise Exception('asdfjkadf')
-        except Exception as e:
-            import sys
-            import traceback
-            traceback.print_exc()
-
 __all__ = ['ProgressPrinterTest']
